==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/link/lang/sk.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'sk', {
	acccessKey: 'Prístupový kľúč',
	advanced: 'Rozšírené',
	advisoryContentType: 'Pomocný typ obsahu',
	advisoryTitle: 'Pomocný titulok',
	anchor: {
		toolbar: 'Kotva',
		menu: 'Upraviť kotvu',
		title: 'Vlastnosti kotvy',
		name: 'Názov kotvy',
		errorName: 'Zadajte prosím názov kotvy',
		remove: 'Odstrániť kotvu'
	},
	anchorId: 'Podľa Id objektu',
	anchorName: 'Podľa mena kotvy',
	charset: 'Priradená znaková sada',
	cssClasses: 'Triedy štýlu',
	emailAddress: 'E-Mailová adresa',
	emailBody: 'Telo správy',
	emailSubject: 'Predmet správy',
	id: 'Id',
	info: 'Informácie o odkaze',
	langCode: 'Orientácia jazyka',
	langDir: 'Orientácia jazyka',
	langDirLTR: 'Zľava doprava (LTR)',
	langDirRTL: 'Sprava doľava (RTL)',
	menu: 'Upraviť odkaz',
	name: 'Názov',
	noAnchors: '(V dokumente nie sú dostupné žiadne kotvy)',
	noEmail: 'Zadajte prosím e-mailovú adresu',
	noUrl: 'Zadajte prosím URL odkazu',
	other: '<iný>',
	popupDependent: 'Závislosť (Netscape)',
	popupFeatures: 'Vlastnosti vyskakovacieho okna',
	popupFullScreen: 'Celá obrazovka (IE)',
	popupLeft: 'Ľavý okraj',
	popupLocationBar: 'Panel umiestnenia (location bar)',
	popupMenuBar: 'Panel ponuky (menu bar)',
	popupResizable: 'Meniteľná veľkosť (resizable)',
	popupScrollBars: 'Posuvníky (scroll bars)',
	popupStatusBar: 'Stavový riadok (status bar)',
	popupToolbar: 'Panel nástrojov (toolbar)',
	popupTop: 'Horný okraj',
	rel: 'Vzťah (rel)',
	selectAnchor: 'Vybrať kotvu',
	styles: 'Štýl',
	tabIndex: 'Poradie prvku (tab index)',
	target: 'Cieľ',
	targetFrame: '<rámec>',
	targetFrameName: 'Názov rámu cieľa',
	targetPopup: '<vyskakovacie okno>',
	targetPopupName: 'Názov vyskakovacieho okna',
	title: 'Odkaz',
	toAnchor: 'Odkaz na kotvu v texte',
	toEmail: 'E-mail',
	toUrl: 'URL',
	toolbar: 'Odkaz',
	type: 'Typ odkazu',
	unlink: 'Odstrániť odkaz',
	upload: 'Nahrať'
} );

==> ckeditor_4.11.1+dfsg.orig.tar.xz: ckeditor-dev-4.11.1/plugins/link/lang/sk.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'sk', {
	acccessKey: 'Prístupový kľúč',
	advanced: 'Rozšírené',
	advisoryContentType: 'Pomocný typ obsahu',
	advisoryTitle: 'Pomocný titulok',
	anchor: {
		toolbar: 'Kotva',
		menu: 'Upraviť kotvu',
		title: 'Vlastnosti kotvy',
		name: 'Názov kotvy',
		errorName: 'Zadajte prosím názov kotvy',
		remove: 'Odstrániť kotvu'
	},
	anchorId: 'Podľa Id objektu',
	anchorName: 'Podľa mena kotvy',
	charset: 'Priradená znaková sada',
	cssClasses: 'Triedy štýlu',
	download: 'Vynútené sťahovanie.',
	displayText: 'Zobraziť text',
	emailAddress: 'E-Mailová adresa',
	emailBody: 'Telo správy',
	emailSubject: 'Predmet správy',
	id: 'Id',
	info: 'Informácie o odkaze',
	langCode: 'Orientácia jazyka',
	langDir: 'Orientácia jazyka',
	langDirLTR: 'Zľava doprava (LTR)',
	langDirRTL: 'Sprava doľava (RTL)',
	menu: 'Upraviť odkaz',
	name: 'Názov',
	noAnchors: '(V dokumente nie sú dostupné žiadne kotvy)',
	noEmail: 'Zadajte prosím e-mailovú adresu',
	noUrl: 'Zadajte prosím URL odkazu',
	noTel: 'Please type the phone number', // MISSING
	other: '<iný>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Závislosť (Netscape)',
	popupFeatures: 'Vlastnosti vyskakovacieho okna',
	popupFullScreen: 'Celá obrazovka (IE)',
	popupLeft: 'Ľavý okraj',
	popupLocationBar: 'Panel umiestnenia (location bar)',
	popupMenuBar: 'Panel ponuky (menu bar)',
	popupResizable: 'Meniteľná veľkosť (resizable)',
	popupScrollBars: 'Posuvníky (scroll bars)',
	popupStatusBar: 'Stavový riadok (status bar)',
	popupToolbar: 'Panel nástrojov (toolbar)',
	popupTop: 'Horný okraj',
	rel: 'Vzťah (rel)',
	selectAnchor: 'Vybrať kotvu',
	styles: 'Štýl',
	tabIndex: 'Poradie prvku (tab index)',
	target: 'Cieľ',
	targetFrame: '<rámec>',
	targetFrameName: 'Názov rámu cieľa',
	targetPopup: '<vyskakovacie okno>',
	targetPopupName: 'Názov vyskakovacieho okna',
	title: 'Odkaz',
	toAnchor: 'Odkaz na kotvu v texte',
	toEmail: 'E-mail',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Odkaz',
	type: 'Typ odkazu',
	unlink: 'Odstrániť odkaz',
	upload: 'Nahrať'
} );
